summaryrefslogtreecommitdiffstats
path: root/regress/integrity.sh
diff options
context:
space:
mode:
authorDamien Miller <djm@mindrot.org>2013-02-14 00:32:33 +0100
committerDamien Miller <djm@mindrot.org>2013-02-14 00:32:33 +0100
commit57f92185288e0101fe9c3f3dfa29ea1619da8354 (patch)
tree9f74e5f034c759bfcb8fc356f90daf4a9e34ab22 /regress/integrity.sh
parent - (djm) [regress/krl.sh] typo; found by Iain Morgan (diff)
downloadopenssh-57f92185288e0101fe9c3f3dfa29ea1619da8354.tar.xz
openssh-57f92185288e0101fe9c3f3dfa29ea1619da8354.zip
- (djm) [regress/integrity.sh] Start fuzzing from offset 2500 (instead
of 2300) to avoid clobbering the end of (non-MAC'd) KEX. Verified by Iain Morgan
Diffstat (limited to '')
-rw-r--r--regress/integrity.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/regress/integrity.sh b/regress/integrity.sh
index 91168fd2e..bcace97e6 100644
--- a/regress/integrity.sh
+++ b/regress/integrity.sh
@@ -3,11 +3,11 @@
tid="integrity"
# start at byte 2300 (i.e. after kex) and corrupt at different offsets
# XXX the test hangs if we modify the low bytes of the packet length
# XXX and ssh tries to read...
tries=10
-startoffset=2300
+startoffset=2500
macs="hmac-sha1 hmac-md5 umac-64@openssh.com umac-128@openssh.com
hmac-sha1-96 hmac-md5-96 hmac-sha2-256 hmac-sha2-512
hmac-sha1-etm@openssh.com hmac-md5-etm@openssh.com
@@ -3,11 +3,11 @@
tid="integrity"
-# start at byte 2300 (i.e. after kex) and corrupt at different offsets
+# start at byte 2500 (i.e. after kex) and corrupt at different offsets
# XXX the test hangs if we modify the low bytes of the packet length
# XXX and ssh tries to read...